from hape.config import Config

class ConfigArgumentParser:

    def create_subparser(self, subparsers):    
        config_parser = subparsers.add_parser("config", help="Commands related to the configurations of the cli")
        
        config_subparser = config_parser.add_subparsers(dest="action")
        check_parser = config_subparser.add_parser("check", help="Check if required configurations for the cli to work are set")

    def run_action(self, args):
        if args.command != "config":
            return
        
        if args.action == "check":
            Config.check_variables()
            print("Configurations are set correctly.")
        else:
            print(f"Error: Invalid {args.comman} action. Use `hape {args.comman} --help` for more details.")
            exit(1)



from hape.logging import logger
from hape.config import Config
from hape.models.deployment_cost_model import DeploymentCost

def bootstrap_application():
    logger.info("Checking configurations.")
    Config.check_variables()

    session = Config.get_db_session()
    try:
        DeploymentCost.initialize_from_sqlalchemy(DeploymentCost)
        logger.info("Database initialized successfully!")
    except Exception as e:
        logger.error(f"Error initializing database: {e}")
    finally:
        session.close()

    logger.info("Application started!")


from hape.services.git_service import GitService

class GitModel:
    def __init__(self):
        self._git_service = GitService()
    
    def clone_project_in_group(self, dir, group_id):
        self._git_service.clone_all_projects(group_id, dir)
    
    def get_repositories(self, dir, prefix):
        return self._git_service.get_git_repositories(dir, prefix)
    
    def git_has_changes(self, repo):
        return self._git_service.git_has_changes(repo)
    
    def git_branch_name(self, repo):
        return self._git_service.git_branch_name(repo)
    
    def commit_and_push(self, repo, message):
        if self.git_has_changes(repo):
            branch_name = self.git_branch_name(repo)
            self._git_service.git_pull(repo, branch_name)
            self._git_service.git_add(repo)
            self._git_service.git_commit(repo, message)
            self._git_service.git_push(repo, branch_name)
            return True
        return False
    
    def pull_project(self, repo):
        branch_name = self.git_branch_name(repo)
        self._git_service.git_pull(repo, branch_name)